marquee package
===============

Submodules
----------

marquee.formatter module
------------------------

.. automodule:: marquee.formatter
    :members:
    :undoc-members:
    :show-inheritance:

marquee.handler module
----------------------

.. automodule:: marquee.handler
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: marquee
    :members:
    :undoc-members:
    :show-inheritance:
